import React from 'react';
import { gql, useQuery, useMutation } from "@apollo/client";
import { useHistory } from "react-router-dom";

import ListAnnonceItem from '../components/list-annonce-item';

const GET_ANNONCES_QUERY = gql`
    query getAnnonces {
    annonces {
        _id
        title
        type
        status
        published
        price
        description
        availabilityDate
        assessments {
        _id
        text  
        annonceId
        }
    }
    }
`;

const DELETE_ANNONCE_MUTATION = gql`
  mutation deleteAnnonce($annonceId: ID!) {
    deleteAnnonce(annonceId: $annonceId) {
      _id
      title
      type
      status
      published
      price
      description
      availabilityDate
      assessments {
        _id
        text
      }
    }
  }
`;

const ListAnnonce = () => {
    let history = useHistory();

    const { loading, error, data } = useQuery(GET_ANNONCES_QUERY);
    const [deleteAnnonce, { 
        loading: mutationLoading,
        error: mutationError,
        data: deleteResponseData 
    }] = useMutation(DELETE_ANNONCE_MUTATION, {
        errorPolicy: 'all'
    });
    
    const navigateToDetail  = (annonceId) => {
        history.push(`/${annonceId}`);
    }

    const onDeletePressed = (e) => {
        
    }

    const onDeleteConfirm = (annonceId) => {
        deleteAnnonce({ variables: { annonceId: annonceId }});
        // close modal
    } 

    if (loading) return (
      <div className="spinner-border text-primary" role="status">
        <span className ="sr-only">Loading...</span>
      </div>
    );
    if (error) return `Error! ${error.message}`;
    
    return (
      <div>
        <div className="row">
          {data.annonces.map((annonce, index) => {
            return (
              <ListAnnonceItem
                key={index}
                annonce={annonce}
                onClick={(e) => navigateToDetail(annonce._id)}
              />
            );
          })}
        </div>
      </div>
    );
}

export default ListAnnonce
